"""
Main interface for support service.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_support import (
        Client,
        DescribeCasesPaginator,
        DescribeCommunicationsPaginator,
        SupportClient,
    )

    session = Session()
    client: SupportClient = session.client("support")

    describe_cases_paginator: DescribeCasesPaginator = client.get_paginator("describe_cases")
    describe_communications_paginator: DescribeCommunicationsPaginator = client.get_paginator("describe_communications")
    ```
"""

from .client import SupportClient
from .paginator import DescribeCasesPaginator, DescribeCommunicationsPaginator

Client = SupportClient


__all__ = ("Client", "DescribeCasesPaginator", "DescribeCommunicationsPaginator", "SupportClient")



"""
Type annotations for support service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_support.type_defs import ResponseMetadataTypeDef

    data: ResponseMetadataTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from typing import IO, Any, Union

from botocore.response import StreamingBody

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Sequence
else:
    from typing import Dict, List, Sequence
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "AddAttachmentsToSetRequestTypeDef",
    "AddAttachmentsToSetResponseTypeDef",
    "AddCommunicationToCaseRequestTypeDef",
    "AddCommunicationToCaseResponseTypeDef",
    "AttachmentDetailsTypeDef",
    "AttachmentOutputTypeDef",
    "AttachmentTypeDef",
    "AttachmentUnionTypeDef",
    "BlobTypeDef",
    "CaseDetailsTypeDef",
    "CategoryTypeDef",
    "CommunicationTypeDef",
    "CommunicationTypeOptionsTypeDef",
    "CreateCaseRequestTypeDef",
    "CreateCaseResponseTypeDef",
    "DateIntervalTypeDef",
    "DescribeAttachmentRequestTypeDef",
    "DescribeAttachmentResponseTypeDef",
    "DescribeCasesRequestPaginateTypeDef",
    "DescribeCasesRequestTypeDef",
    "DescribeCasesResponseTypeDef",
    "DescribeCommunicationsRequestPaginateTypeDef",
    "DescribeCommunicationsRequestTypeDef",
    "DescribeCommunicationsResponseTypeDef",
    "DescribeCreateCaseOptionsRequestTypeDef",
    "DescribeCreateCaseOptionsResponseTypeDef",
    "DescribeServicesRequestTypeDef",
    "DescribeServicesResponseTypeDef",
    "DescribeSeverityLevelsRequestTypeDef",
    "DescribeSeverityLevelsResponseTypeDef",
    "DescribeSupportedLanguagesRequestTypeDef",
    "DescribeSupportedLanguagesResponseTypeDef",
    "DescribeTrustedAdvisorCheckRefreshStatusesRequestTypeDef",
    "DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef",
    "DescribeTrustedAdvisorCheckResultRequestTypeDef",
    "DescribeTrustedAdvisorCheckResultResponseTypeDef",
    "DescribeTrustedAdvisorCheckSummariesRequestTypeDef",
    "DescribeTrustedAdvisorCheckSummariesResponseTypeDef",
    "DescribeTrustedAdvisorChecksRequestTypeDef",
    "DescribeTrustedAdvisorChecksResponseTypeDef",
    "PaginatorConfigTypeDef",
    "RecentCaseCommunicationsTypeDef",
    "RefreshTrustedAdvisorCheckRequestTypeDef",
    "RefreshTrustedAdvisorCheckResponseTypeDef",
    "ResolveCaseRequestTypeDef",
    "ResolveCaseResponseTypeDef",
    "ResponseMetadataTypeDef",
    "ServiceTypeDef",
    "SeverityLevelTypeDef",
    "SupportedHourTypeDef",
    "SupportedLanguageTypeDef",
    "TrustedAdvisorCategorySpecificSummaryTypeDef",
    "TrustedAdvisorCheckDescriptionTypeDef",
    "TrustedAdvisorCheckRefreshStatusTypeDef",
    "TrustedAdvisorCheckResultTypeDef",
    "TrustedAdvisorCheckSummaryTypeDef",
    "TrustedAdvisorCostOptimizingSummaryTypeDef",
    "TrustedAdvisorResourceDetailTypeDef",
    "TrustedAdvisorResourcesSummaryTypeDef",
)


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class AddCommunicationToCaseRequestTypeDef(TypedDict):
    communicationBody: str
    caseId: NotRequired[str]
    ccEmailAddresses: NotRequired[Sequence[str]]
    attachmentSetId: NotRequired[str]


class AttachmentDetailsTypeDef(TypedDict):
    attachmentId: NotRequired[str]
    fileName: NotRequired[str]


class AttachmentOutputTypeDef(TypedDict):
    fileName: NotRequired[str]
    data: NotRequired[bytes]


BlobTypeDef = Union[str, bytes, IO[Any], StreamingBody]


class CategoryTypeDef(TypedDict):
    code: NotRequired[str]
    name: NotRequired[str]


class DateIntervalTypeDef(TypedDict):
    startDateTime: NotRequired[str]
    endDateTime: NotRequired[str]


class SupportedHourTypeDef(TypedDict):
    startTime: NotRequired[str]
    endTime: NotRequired[str]


class CreateCaseRequestTypeDef(TypedDict):
    subject: str
    communicationBody: str
    serviceCode: NotRequired[str]
    severityCode: NotRequired[str]
    categoryCode: NotRequired[str]
    ccEmailAddresses: NotRequired[Sequence[str]]
    language: NotRequired[str]
    issueType: NotRequired[str]
    attachmentSetId: NotRequired[str]


class DescribeAttachmentRequestTypeDef(TypedDict):
    attachmentId: str


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class DescribeCasesRequestTypeDef(TypedDict):
    caseIdList: NotRequired[Sequence[str]]
    displayId: NotRequired[str]
    afterTime: NotRequired[str]
    beforeTime: NotRequired[str]
    includeResolvedCases: NotRequired[bool]
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]
    language: NotRequired[str]
    includeCommunications: NotRequired[bool]


class DescribeCommunicationsRequestTypeDef(TypedDict):
    caseId: str
    beforeTime: NotRequired[str]
    afterTime: NotRequired[str]
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]


class DescribeCreateCaseOptionsRequestTypeDef(TypedDict):
    issueType: str
    serviceCode: str
    language: str
    categoryCode: str


class DescribeServicesRequestTypeDef(TypedDict):
    serviceCodeList: NotRequired[Sequence[str]]
    language: NotRequired[str]


class DescribeSeverityLevelsRequestTypeDef(TypedDict):
    language: NotRequired[str]


class SeverityLevelTypeDef(TypedDict):
    code: NotRequired[str]
    name: NotRequired[str]


class DescribeSupportedLanguagesRequestTypeDef(TypedDict):
    issueType: str
    serviceCode: str
    categoryCode: str


class SupportedLanguageTypeDef(TypedDict):
    code: NotRequired[str]
    language: NotRequired[str]
    display: NotRequired[str]


class DescribeTrustedAdvisorCheckRefreshStatusesRequestTypeDef(TypedDict):
    checkIds: Sequence[str]


class TrustedAdvisorCheckRefreshStatusTypeDef(TypedDict):
    checkId: str
    status: str
    millisUntilNextRefreshable: int


class DescribeTrustedAdvisorCheckResultRequestTypeDef(TypedDict):
    checkId: str
    language: NotRequired[str]


class DescribeTrustedAdvisorCheckSummariesRequestTypeDef(TypedDict):
    checkIds: Sequence[str]


class DescribeTrustedAdvisorChecksRequestTypeDef(TypedDict):
    language: str


TrustedAdvisorCheckDescriptionTypeDef = TypedDict(
    "TrustedAdvisorCheckDescriptionTypeDef",
    {
        "id": str,
        "name": str,
        "description": str,
        "category": str,
        "metadata": List[str],
    },
)


class RefreshTrustedAdvisorCheckRequestTypeDef(TypedDict):
    checkId: str


class ResolveCaseRequestTypeDef(TypedDict):
    caseId: NotRequired[str]


class TrustedAdvisorCostOptimizingSummaryTypeDef(TypedDict):
    estimatedMonthlySavings: float
    estimatedPercentMonthlySavings: float


class TrustedAdvisorResourceDetailTypeDef(TypedDict):
    status: str
    resourceId: str
    metadata: List[str]
    region: NotRequired[str]
    isSuppressed: NotRequired[bool]


class TrustedAdvisorResourcesSummaryTypeDef(TypedDict):
    resourcesProcessed: int
    resourcesFlagged: int
    resourcesIgnored: int
    resourcesSuppressed: int


class AddAttachmentsToSetResponseTypeDef(TypedDict):
    attachmentSetId: str
    expiryTime: str
    ResponseMetadata: ResponseMetadataTypeDef


class AddCommunicationToCaseResponseTypeDef(TypedDict):
    result: bool
    ResponseMetadata: ResponseMetadataTypeDef


class CreateCaseResponseTypeDef(TypedDict):
    caseId: str
    ResponseMetadata: ResponseMetadataTypeDef


class ResolveCaseResponseTypeDef(TypedDict):
    initialCaseStatus: str
    finalCaseStatus: str
    ResponseMetadata: ResponseMetadataTypeDef


class CommunicationTypeDef(TypedDict):
    caseId: NotRequired[str]
    body: NotRequired[str]
    submittedBy: NotRequired[str]
    timeCreated: NotRequired[str]
    attachmentSet: NotRequired[List[AttachmentDetailsTypeDef]]


class DescribeAttachmentResponseTypeDef(TypedDict):
    attachment: AttachmentOutputTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class AttachmentTypeDef(TypedDict):
    fileName: NotRequired[str]
    data: NotRequired[BlobTypeDef]


class ServiceTypeDef(TypedDict):
    code: NotRequired[str]
    name: NotRequired[str]
    categories: NotRequired[List[CategoryTypeDef]]


CommunicationTypeOptionsTypeDef = TypedDict(
    "CommunicationTypeOptionsTypeDef",
    {
        "type": NotRequired[str],
        "supportedHours": NotRequired[List[SupportedHourTypeDef]],
        "datesWithoutSupport": NotRequired[List[DateIntervalTypeDef]],
    },
)


class DescribeCasesRequestPaginateTypeDef(TypedDict):
    caseIdList: NotRequired[Sequence[str]]
    displayId: NotRequired[str]
    afterTime: NotRequired[str]
    beforeTime: NotRequired[str]
    includeResolvedCases: NotRequired[bool]
    language: NotRequired[str]
    includeCommunications: NotRequired[bool]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class DescribeCommunicationsRequestPaginateTypeDef(TypedDict):
    caseId: str
    beforeTime: NotRequired[str]
    afterTime: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class DescribeSeverityLevelsResponseTypeDef(TypedDict):
    severityLevels: List[SeverityLevelTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeSupportedLanguagesResponseTypeDef(TypedDict):
    supportedLanguages: List[SupportedLanguageTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef(TypedDict):
    statuses: List[TrustedAdvisorCheckRefreshStatusTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class RefreshTrustedAdvisorCheckResponseTypeDef(TypedDict):
    status: TrustedAdvisorCheckRefreshStatusTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeTrustedAdvisorChecksResponseTypeDef(TypedDict):
    checks: List[TrustedAdvisorCheckDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class TrustedAdvisorCategorySpecificSummaryTypeDef(TypedDict):
    costOptimizing: NotRequired[TrustedAdvisorCostOptimizingSummaryTypeDef]


class DescribeCommunicationsResponseTypeDef(TypedDict):
    communications: List[CommunicationTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]


class RecentCaseCommunicationsTypeDef(TypedDict):
    communications: NotRequired[List[CommunicationTypeDef]]
    nextToken: NotRequired[str]


AttachmentUnionTypeDef = Union[AttachmentTypeDef, AttachmentOutputTypeDef]


class DescribeServicesResponseTypeDef(TypedDict):
    services: List[ServiceTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeCreateCaseOptionsResponseTypeDef(TypedDict):
    languageAvailability: str
    communicationTypes: List[CommunicationTypeOptionsTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class TrustedAdvisorCheckResultTypeDef(TypedDict):
    checkId: str
    timestamp: str
    status: str
    resourcesSummary: TrustedAdvisorResourcesSummaryTypeDef
    categorySpecificSummary: TrustedAdvisorCategorySpecificSummaryTypeDef
    flaggedResources: List[TrustedAdvisorResourceDetailTypeDef]


class TrustedAdvisorCheckSummaryTypeDef(TypedDict):
    checkId: str
    timestamp: str
    status: str
    resourcesSummary: TrustedAdvisorResourcesSummaryTypeDef
    categorySpecificSummary: TrustedAdvisorCategorySpecificSummaryTypeDef
    hasFlaggedResources: NotRequired[bool]


class CaseDetailsTypeDef(TypedDict):
    caseId: NotRequired[str]
    displayId: NotRequired[str]
    subject: NotRequired[str]
    status: NotRequired[str]
    serviceCode: NotRequired[str]
    categoryCode: NotRequired[str]
    severityCode: NotRequired[str]
    submittedBy: NotRequired[str]
    timeCreated: NotRequired[str]
    recentCommunications: NotRequired[RecentCaseCommunicationsTypeDef]
    ccEmailAddresses: NotRequired[List[str]]
    language: NotRequired[str]


class AddAttachmentsToSetRequestTypeDef(TypedDict):
    attachments: Sequence[AttachmentUnionTypeDef]
    attachmentSetId: NotRequired[str]


class DescribeTrustedAdvisorCheckResultResponseTypeDef(TypedDict):
    result: TrustedAdvisorCheckResultTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeTrustedAdvisorCheckSummariesResponseTypeDef(TypedDict):
    summaries: List[TrustedAdvisorCheckSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeCasesResponseTypeDef(TypedDict):
    cases: List[CaseDetailsTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]



"""
Main CLI entrypoint.

Copyright 2025 Vlad Emelianov
"""

import sys


def print_info() -> None:
    """
    Print package info to stdout.
    """
    sys.stdout.write(
        "Type annotations for boto3 Support 1.38.0\n"
        "Version:         1.38.0\n"
        "Builder version: 8.10.1\n"
        "Docs:            https://youtype.github.io/types_boto3_docs/types_boto3_support//\n"
        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support.html#support\n"
        "Other services:  https://pypi.org/project/boto3-stubs/\n"
        "Changelog:       https://github.com/youtype/mypy_boto3_builder/releases\n"
    )


def print_version() -> None:
    """
    Print package version to stdout.
    """
    sys.stdout.write("1.38.0\n")


def main() -> None:
    """
    Main CLI entrypoint.
    """
    if "--version" in sys.argv:
        print_version()
        return
    print_info()


if __name__ == "__main__":
    main()



"""
Type annotations for support service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_support.client import SupportClient

    session = Session()
    client: SupportClient = session.client("support")
    ```
"""

from __future__ import annotations

import sys
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import DescribeCasesPaginator, DescribeCommunicationsPaginator
from .type_defs import (
    AddAttachmentsToSetRequestTypeDef,
    AddAttachmentsToSetResponseTypeDef,
    AddCommunicationToCaseRequestTypeDef,
    AddCommunicationToCaseResponseTypeDef,
    CreateCaseRequestTypeDef,
    CreateCaseResponseTypeDef,
    DescribeAttachmentRequestTypeDef,
    DescribeAttachmentResponseTypeDef,
    DescribeCasesRequestTypeDef,
    DescribeCasesResponseTypeDef,
    DescribeCommunicationsRequestTypeDef,
    DescribeCommunicationsResponseTypeDef,
    DescribeCreateCaseOptionsRequestTypeDef,
    DescribeCreateCaseOptionsResponseTypeDef,
    DescribeServicesRequestTypeDef,
    DescribeServicesResponseTypeDef,
    DescribeSeverityLevelsRequestTypeDef,
    DescribeSeverityLevelsResponseTypeDef,
    DescribeSupportedLanguagesRequestTypeDef,
    DescribeSupportedLanguagesResponseTypeDef,
    DescribeTrustedAdvisorCheckRefreshStatusesRequestTypeDef,
    DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef,
    DescribeTrustedAdvisorCheckResultRequestTypeDef,
    DescribeTrustedAdvisorCheckResultResponseTypeDef,
    DescribeTrustedAdvisorChecksRequestTypeDef,
    DescribeTrustedAdvisorChecksResponseTypeDef,
    DescribeTrustedAdvisorCheckSummariesRequestTypeDef,
    DescribeTrustedAdvisorCheckSummariesResponseTypeDef,
    RefreshTrustedAdvisorCheckRequestTypeDef,
    RefreshTrustedAdvisorCheckResponseTypeDef,
    ResolveCaseRequestTypeDef,
    ResolveCaseResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack

__all__ = ("SupportClient",)

class Exceptions(BaseClientExceptions):
    AttachmentIdNotFound: Type[BotocoreClientError]
    AttachmentLimitExceeded: Type[BotocoreClientError]
    AttachmentSetExpired: Type[BotocoreClientError]
    AttachmentSetIdNotFound: Type[BotocoreClientError]
    AttachmentSetSizeLimitExceeded: Type[BotocoreClientError]
    CaseCreationLimitExceeded: Type[BotocoreClientError]
    CaseIdNotFound: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    DescribeAttachmentLimitExceeded: Type[BotocoreClientError]
    InternalServerError: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]

class SupportClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support.html#Support.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        SupportClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support.html#Support.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#generate_presigned_url)
        """

    def add_attachments_to_set(
        self, **kwargs: Unpack[AddAttachmentsToSetRequestTypeDef]
    ) -> AddAttachmentsToSetResponseTypeDef:
        """
        Adds one or more attachments to an attachment set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/add_attachments_to_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#add_attachments_to_set)
        """

    def add_communication_to_case(
        self, **kwargs: Unpack[AddCommunicationToCaseRequestTypeDef]
    ) -> AddCommunicationToCaseResponseTypeDef:
        """
        Adds additional customer communication to an Amazon Web Services Support case.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/add_communication_to_case.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#add_communication_to_case)
        """

    def create_case(self, **kwargs: Unpack[CreateCaseRequestTypeDef]) -> CreateCaseResponseTypeDef:
        """
        Creates a case in the Amazon Web Services Support Center.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/create_case.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#create_case)
        """

    def describe_attachment(
        self, **kwargs: Unpack[DescribeAttachmentRequestTypeDef]
    ) -> DescribeAttachmentResponseTypeDef:
        """
        Returns the attachment that has the specified ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_attachment.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_attachment)
        """

    def describe_cases(
        self, **kwargs: Unpack[DescribeCasesRequestTypeDef]
    ) -> DescribeCasesResponseTypeDef:
        """
        Returns a list of cases that you specify by passing one or more case IDs.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_cases.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_cases)
        """

    def describe_communications(
        self, **kwargs: Unpack[DescribeCommunicationsRequestTypeDef]
    ) -> DescribeCommunicationsResponseTypeDef:
        """
        Returns communications and attachments for one or more support cases.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_communications.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_communications)
        """

    def describe_create_case_options(
        self, **kwargs: Unpack[DescribeCreateCaseOptionsRequestTypeDef]
    ) -> DescribeCreateCaseOptionsResponseTypeDef:
        """
        Returns a list of CreateCaseOption types along with the corresponding supported
        hours and language availability.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_create_case_options.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_create_case_options)
        """

    def describe_services(
        self, **kwargs: Unpack[DescribeServicesRequestTypeDef]
    ) -> DescribeServicesResponseTypeDef:
        """
        Returns the current list of Amazon Web Services services and a list of service
        categories for each service.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_services.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_services)
        """

    def describe_severity_levels(
        self, **kwargs: Unpack[DescribeSeverityLevelsRequestTypeDef]
    ) -> DescribeSeverityLevelsResponseTypeDef:
        """
        Returns the list of severity levels that you can assign to a support case.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_severity_levels.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_severity_levels)
        """

    def describe_supported_languages(
        self, **kwargs: Unpack[DescribeSupportedLanguagesRequestTypeDef]
    ) -> DescribeSupportedLanguagesResponseTypeDef:
        """
        Returns a list of supported languages for a specified
        <code>categoryCode</code>, <code>issueType</code> and <code>serviceCode</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_supported_languages.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_supported_languages)
        """

    def describe_trusted_advisor_check_refresh_statuses(
        self, **kwargs: Unpack[DescribeTrustedAdvisorCheckRefreshStatusesRequestTypeDef]
    ) -> DescribeTrustedAdvisorCheckRefreshStatusesResponseTypeDef:
        """
        Returns the refresh status of the Trusted Advisor checks that have the
        specified check IDs.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_trusted_advisor_check_refresh_statuses.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_trusted_advisor_check_refresh_statuses)
        """

    def describe_trusted_advisor_check_result(
        self, **kwargs: Unpack[DescribeTrustedAdvisorCheckResultRequestTypeDef]
    ) -> DescribeTrustedAdvisorCheckResultResponseTypeDef:
        """
        Returns the results of the Trusted Advisor check that has the specified check
        ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_trusted_advisor_check_result.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_trusted_advisor_check_result)
        """

    def describe_trusted_advisor_check_summaries(
        self, **kwargs: Unpack[DescribeTrustedAdvisorCheckSummariesRequestTypeDef]
    ) -> DescribeTrustedAdvisorCheckSummariesResponseTypeDef:
        """
        Returns the results for the Trusted Advisor check summaries for the check IDs
        that you specified.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_trusted_advisor_check_summaries.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_trusted_advisor_check_summaries)
        """

    def describe_trusted_advisor_checks(
        self, **kwargs: Unpack[DescribeTrustedAdvisorChecksRequestTypeDef]
    ) -> DescribeTrustedAdvisorChecksResponseTypeDef:
        """
        Returns information about all available Trusted Advisor checks, including the
        name, ID, category, description, and metadata.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/describe_trusted_advisor_checks.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#describe_trusted_advisor_checks)
        """

    def refresh_trusted_advisor_check(
        self, **kwargs: Unpack[RefreshTrustedAdvisorCheckRequestTypeDef]
    ) -> RefreshTrustedAdvisorCheckResponseTypeDef:
        """
        Refreshes the Trusted Advisor check that you specify using the check ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/refresh_trusted_advisor_check.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#refresh_trusted_advisor_check)
        """

    def resolve_case(
        self, **kwargs: Unpack[ResolveCaseRequestTypeDef]
    ) -> ResolveCaseResponseTypeDef:
        """
        Resolves a support case.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/resolve_case.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#resolve_case)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["describe_cases"]
    ) -> DescribeCasesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["describe_communications"]
    ) -> DescribeCommunicationsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/client/#get_paginator)
        """



"""
Type annotations for support service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_support.client import SupportClient
    from types_boto3_support.paginator import (
        DescribeCasesPaginator,
        DescribeCommunicationsPaginator,
    )

    session = Session()
    client: SupportClient = session.client("support")

    describe_cases_paginator: DescribeCasesPaginator = client.get_paginator("describe_cases")
    describe_communications_paginator: DescribeCommunicationsPaginator = client.get_paginator("describe_communications")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeCasesRequestPaginateTypeDef,
    DescribeCasesResponseTypeDef,
    DescribeCommunicationsRequestPaginateTypeDef,
    DescribeCommunicationsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("DescribeCasesPaginator", "DescribeCommunicationsPaginator")


if TYPE_CHECKING:
    _DescribeCasesPaginatorBase = Paginator[DescribeCasesResponseTypeDef]
else:
    _DescribeCasesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeCasesPaginator(_DescribeCasesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCases.html#Support.Paginator.DescribeCases)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecasespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeCasesRequestPaginateTypeDef]
    ) -> PageIterator[DescribeCasesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCases.html#Support.Paginator.DescribeCases.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecasespaginator)
        """


if TYPE_CHECKING:
    _DescribeCommunicationsPaginatorBase = Paginator[DescribeCommunicationsResponseTypeDef]
else:
    _DescribeCommunicationsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeCommunicationsPaginator(_DescribeCommunicationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCommunications.html#Support.Paginator.DescribeCommunications)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecommunicationspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeCommunicationsRequestPaginateTypeDef]
    ) -> PageIterator[DescribeCommunicationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCommunications.html#Support.Paginator.DescribeCommunications.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecommunicationspaginator)
        """
